@@ -544,7 +544,8 @@ L<Astro::App::Satpass2|Astro::App::Satpass2>.
 =head1 SUPPORT
 
 Support is by the author. Please file bug reports at
-L<https://rt.cpan.org>, or in electronic mail to the author.
+L<https://github.com/trwyant/perl-Astro-App-Satpass2/issues>, or in
+electronic mail to the author.
 
 =head1 AUTHOR
 
@@ -552,7 +553,7 @@ Thomas R. Wyant, III F<wyant at cpan dot org>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2011-2020 by Thomas R. Wyant, III
+Copyright (C) 2011-2021 by Thomas R. Wyant, III
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl 5.10.0. For more details, see the full text
